@@ -12,6 +12,7 @@ from typing import TYPE_CHECKING, List
 
 # Houdini Package Runner
 import houdini_package_runner.parser
+import houdini_package_runner.runners.utils
 import houdini_package_runner.utils
 from houdini_package_runner.discoverers import package
 from houdini_package_runner.runners.base import HoudiniPackageRunner
@@ -102,7 +103,7 @@ Any unknown args will be passed along to the black command.
         """
         flags = []
 
-        flags.extend(self.config.get_config_data("flags", item, file_path))
+        flags.extend(self.config.get_config_data("command", item, file_path))
 
         flags.extend(self.extra_args)
 
@@ -116,10 +117,16 @@ Any unknown args will be passed along to the black command.
 
         command.extend(flags)
 
+        # Remove any duplicate items that could result in unexpected behavior.
+        command = houdini_package_runner.utils.remove_duplicate_flags(command)
+
         command.append(str(file_path))
 
+        if self.verbose:
+            houdini_package_runner.runners.utils.print_runner_command(item, command)
+
         return houdini_package_runner.utils.execute_subprocess_command(
-            command, verbose=self._verbose
+            command, verbose=self.verbose
         )
 
 
